==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/components/management-toolbar/search/SearchSubnavigationBar.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/components/management-toolbar/search/SearchSubnavigationBar.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../../utils/lang.es', '../../button/Button.es', './SearchContext.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _lang = _interopRequireDefault(require("../../../utils/lang.es"));

  var _Button = _interopRequireDefault(require("../../button/Button.es"));

  var _SearchContext = _interopRequireDefault(require("./SearchContext.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var isLoading = _ref.isLoading,
        totalCount = _ref.totalCount;

    var _useContext = (0, _react.useContext)(_SearchContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        keywords = _useContext2[0].keywords,
        dispatch = _useContext2[1];

    var invisible = isLoading ? 'invisible' : '';
    return _react["default"].createElement(_react["default"].Fragment, null, keywords && _react["default"].createElement("nav", {
      className: "tbar tbar-inline-xs-down subnav-tbar subnav-tbar-primary ".concat(invisible)
    }, _react["default"].createElement("div", {
      className: "container-fluid container-fluid-max-xl"
    }, _react["default"].createElement("ul", {
      className: "tbar-nav tbar-nav-wrap"
    }, _react["default"].createElement("li", {
      className: "tbar-item tbar-item-expand"
    }, _react["default"].createElement("div", {
      className: "tbar-section"
    }, _react["default"].createElement("span", {
      className: "component-text text-truncate-inline"
    }, _react["default"].createElement("span", {
      className: "text-truncate"
    }, _lang["default"].sub(Liferay.Language.get('x-results-for-x'), [totalCount, keywords]))))), _react["default"].createElement("li", {
      className: "tbar-item"
    }, _react["default"].createElement("div", {
      className: "tbar-section"
    }, _react["default"].createElement(_Button["default"], {
      className: "component-link tbar-link",
      displayType: "unstyled",
      onClick: function onClick() {
        return dispatch({
          keywords: '',
          type: 'SEARCH'
        });
      }
    }, "Clear")))))));
  };

  exports["default"] = _default;
  //# sourceMappingURL=SearchSubnavigationBar.es.js.map
});
//# sourceMappingURL=SearchSubnavigationBar.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/components/management-toolbar/search/SearchSubnavigationBar.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/components/management-toolbar/search/SearchSubnavigationBar.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../../utils/lang.es', '../../button/Button.es', './SearchContext.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _lang = _interopRequireDefault(require("../../../utils/lang.es"));

  var _Button = _interopRequireDefault(require("../../button/Button.es"));

  var _SearchContext = _interopRequireDefault(require("./SearchContext.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var isLoading = _ref.isLoading,
        totalCount = _ref.totalCount;

    var _useContext = (0, _react.useContext)(_SearchContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        keywords = _useContext2[0].keywords,
        dispatch = _useContext2[1];

    var invisible = isLoading ? 'invisible' : '';
    return _react["default"].createElement(_react["default"].Fragment, null, keywords && _react["default"].createElement("nav", {
      className: "tbar tbar-inline-xs-down subnav-tbar subnav-tbar-primary ".concat(invisible)
    }, _react["default"].createElement("div", {
      className: "container-fluid container-fluid-max-xl"
    }, _react["default"].createElement("ul", {
      className: "tbar-nav tbar-nav-wrap"
    }, _react["default"].createElement("li", {
      className: "tbar-item tbar-item-expand"
    }, _react["default"].createElement("div", {
      className: "tbar-section"
    }, _react["default"].createElement("span", {
      className: "component-text text-truncate-inline"
    }, _react["default"].createElement("span", {
      className: "text-truncate"
    }, _lang["default"].sub(Liferay.Language.get('x-results-for-x'), [totalCount, keywords]))))), _react["default"].createElement("li", {
      className: "tbar-item"
    }, _react["default"].createElement("div", {
      className: "tbar-section"
    }, _react["default"].createElement(_Button["default"], {
      className: "component-link tbar-link",
      displayType: "unstyled",
      onClick: function onClick() {
        return dispatch({
          keywords: '',
          type: 'SEARCH'
        });
      }
    }, "Clear")))))));
  };

  exports["default"] = _default;
  //# sourceMappingURL=SearchSubnavigationBar.es.js.map
});
//# sourceMappingURL=SearchSubnavigationBar.es.js.map
